@@ -1,4 +1,3 @@
-#![feature(async_closure, bool_to_option)]
 //! # site_icons
 //! An efficient website icon scraper.
 //!
@@ -6,7 +5,7 @@
 //! ```rust
 //! use site_icons::Icons;
 //!
-//! let icons = Icons::new();
+//! let mut icons = Icons::new();
 //! // scrape the icons from a url
 //! icons.load_website("https://github.com").await?;
 //!
@@ -15,7 +14,7 @@
 //!
 //! // entries are sorted from highest to lowest resolution
 //! for icon in entries {
-//!   println("{:?}", icon)
+//!   println!("{:?}", icon)
 //! }
 //! ```
 
@@ -47,3 +46,24 @@ static CLIENT: Lazy<Client> = Lazy::new(|| {
   headers.insert(USER_AGENT, HeaderValue::from_str("Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/88.0.4324.104 Safari/537.36").unwrap());
   Client::builder().default_headers(headers).build().unwrap()
 });
+
+#[cfg(test)]
+mod tests {
+  use super::*;
+  #[tokio::test]
+  async fn test_icons() {
+    let mut icons = Icons::new();
+    // scrape the icons from a url
+    icons.load_website("https://github.com").await.unwrap();
+
+    // fetch all icons, ensuring they exist & determining size
+    let entries = icons.entries().await;
+
+    // entries are sorted from highest to lowest resolution
+    for icon in &entries {
+      println!("{:?}", icon)
+    }
+
+    assert_eq!(entries.len() > 0, true);
+  }
+}
